<template>
  <basic-container>
    <avue-crud :option="option"
               :table-loading="loading"
               :data="data"
               :page.sync="page"
               :permission="permissionList"
               :before-open="beforeOpen"
               v-model="form"
               ref="crud"
               @row-del="rowDel"
               @search-change="searchChange"
               @search-reset="searchReset"
               @selection-change="selectionChange"
               @current-change="currentChange"
               @size-change="sizeChange"
               @refresh-change="refreshChange"
               @on-load="onLoad">
      <template slot="menuLeft">
        <el-button type="primary"
                   size="small"
                   plain
                   icon="el-icon-upload2"
                   @click="handleUpload">上 传
        </el-button>
        <el-button type="primary"
                   size="small"
                   plain
                   icon="el-icon-edit"
                   @click="handleEdit">修 改
        </el-button>
        <el-button type="danger"
                   size="small"
                   icon="el-icon-delete"
                   plain
                   @click="handleDelete">删 除
        </el-button>
      </template>
      <template slot-scope="scope" slot="menu">
        <el-button type="text"
                   icon="el-icon-download"
                   size="small"
                   @click="handleDownload(scope.row)">下载
        </el-button>
      </template>
    </avue-crud>
    <el-dialog title="附件管理"
               append-to-body
               :visible.sync="attachBox"
               width="555px">
      <avue-form ref="form" :option="attachOption" v-model="attachForm" :upload-before="uploadBefore"  :upload-after="uploadAfter" :upload-error="uploadError">
      </avue-form>
    </el-dialog>
  </basic-container>
</template>

<script>
import {getList, getFile,upload,update, remove,download} from "@/api/resource/file";
import {mapGetters} from "vuex";
import {dateFormat} from "@/util/date";

export default {
  props: ["options","visible"],
  data() {
    return {
      form: {},
      query: {},
      params:{},
      loading: false,
      page: {
        pageSize: 10,
        currentPage: 1,
        total: 0
      },
      attachBox: false,
      selectionList: [],
      option: {
        height: 'auto',
        calcHeight: 30,
        tip: false,
        searchShow: true,
        searchMenuSpan: 6,
        border: true,
        index: true,
        viewBtn: true,
        selection: true,
        dialogClickModal: false,
        column: [
          {
            label: "文件名称",
            prop: "name",
            search: true,
            /*formatter:function(d){
              if(this.options.hasDownloadRight != false){
                //说明有下载文件的权限，那么我们就添加一个超链接
                return ''//'<a name="filenamedownloadlink " class="layui-btn layui-btn-intable" lay-event="PREVIEW" fileoid="' + d.oid +'">' + (d.id?d.id:d.name) + '</a>';
              }else{
                return d.id || d.name;
              }
            }*/
          },
          {
            label: "文件大小",
            prop: "fileSize",
            formatter:function(d){
              if(!d.fileSize || d.fileSize == null || d.fileSize*1 == 0 || isNaN(d.fileSize*1) ){
                return "未知大小";
              }else{
                //原始大小是B
                var filesize = d.fileSize*1;
                if(filesize>1024*1024*1024*1024){
                  return parseInt(filesize/(1024*1024*1024*1024)) + "TB";
                }else if(filesize> 1024*1024*1024){
                  return parseInt(filesize/(1024*1024*1024)) + "GB";
                }else if(filesize> 1024*1024){
                  return parseInt(filesize/(1024*1024)) + "MB";
                }else if(filesize> 1024){
                  return parseInt(filesize/1024) + "KB";
                }else {
                  return filesize + "B";
                }
              }
            }
          },
          /*{
            label: "密级",
            prop: "secretGradeText"
          },
          {
            label: "文档类别",
            prop: "fileDocClassifyName"
          },*/
          {
            label: "创建者",
            prop: "creator"
          },
          {
            label: "创建时间",
            prop: "createTime"
          },
        ]
      },
      columnType: {
        text: "input",
        combox: "select",
        truefalse: "switch",
        number: "number",
        textarea: "textarea",
        datetime: "datetime",
        date: "date",
        refer: "refer",
      },
      data: [{
        btmname: "fileobject",
        createTime: "2023-06-14 16:08:50.002",
        creator: "1",
        fileDocClassify: "undefined",
        fileDocClassifyName: null,
        fileExtension: "png",
        filePath: "VolumnFactoryService:/f87a4c92-ce6e-458b-aad0-0c76bd5eeb35\\54120082-76aa-4092-abbf-b13cb40606c5",
        fileSize: 858,
        id: "assignRole",
        name: "assignRole",
        nameOid: "9FF4C05D-4EFA-F00B-0080-5ABB50257D4E",
        oid: "54120082-76aa-4092-abbf-b13cb40606c5",
        ownBtmname: "wupin",
        ownbizOid: "6EF696C3-CD87-0E7C-1EA1-8DE3913A95C9",
        owner: "1",
        secretGrade: null,
        secretGradeText: null
      }],
      attachForm: {},
      attachOption: {
        submitBtn: false,
        emptyBtn: false,
        column: [{
          prop: 'fileDocClassify',
          label: '文件类型',
          props: {
            label: 'value',
            value: 'key'
          },
          change: () => {
            (!!this.options.fileDocClassifyCombox) && this.changeFun('fileDocClassify');
          },
          blur: () => {
            (!this.options.fileDocClassifyCombox) && this.changeFun('fileDocClassify');
          },
          value: this.options.fileDocClassify || "ADMIN_SHARE",
          type: (!this.options.fileDocClassifyCombox) ? 'input' : 'select',
          dicData: (this.options.fileDocClassifyCombox || []),//[{key: 'text', value: '文本框'}]
          display: (!!this.options.fileDocClassifyCombox)
        }, {
          label: '附件上传',
          prop: 'attachFile',
          type: 'upload',
          dragFile: true,
          accept: this.options.uploadAccept || 'file',
          loadText: '文件上传中，请稍等',
          span: 24,
          propsHttp: {
            res: 'data'
          },
          data: {
            ownbizOid:this.options.ownbizOid || "share",
            ownBtmname:this.options.ownbizBtm || "share",
            fileDocClassify:this.options.fileDocClassify || "ADMIN_SHARE",
            fileDocClassifyName:this.options.fileDocClassifyName || "管理员共享文件"
          },
          action: "/api/ubcs-resource/fileController/uploadFile"
        }
        ]
      }
    };
  },
  computed: {
    ...mapGetters(["permission"]),
    permissionList() {
      return {
        addBtn: false,
        editBtn: false,
        viewBtn: false,
        delBtn: this.vaildData(this.permission.attach_delete, false)
      };
    },
    oids() {
      let oids = [];
      this.selectionList.forEach(ele => {
        oids.push(ele.oid);
      });
      return oids.join(",");
    }
  },
  mounted() {
    this.setFormItem();
    this.setParams()
  },
  methods: {
    setFormItem(){
      /*this.options.formItems=[{
        field: 'fileDocClassify11',
        title: '文件类型',
        type:  'combox',
        data: [{key: 'text', value: '文本框'},{key: 'number', value: '数字框'}]
      }]*/
      if(this.options && this.options.formItems){
        this.options.formItems.forEach(item => {
          // 设置表单校验的规则，文本
          let message = "请选择";
          let trigger = "change";
          if (item.type === "text") {
            message = "请输入";
            trigger = "blur";
          }
          this.attachOption.column.push( {
            ...item,
            label: item.title,
            prop: item.field,
            display: !item.hidden,
            value: item.defaultValue,
            disabled: item.readOnly,
            type: this.columnType[item.type],
            dicData: this.getDataList(item.type, item.data),
            change: () => {
              if(item.type !== "text"  && item.type !== "number" && item.type !== "textarea"){
                this.changeFun(item.field);
              }
            },
            blur: () => {
              if(item.type == "text"  || item.type == "number" || item.type == "textarea"){
                this.changeFun(item.field);
              }
            },
            rules: [
              {
                required: item.required,
                message: `请${message}${item.title}`,
                trigger,
              },
              {
                // 如果没有正则则匹配任何字符
                pattern: item.verify ? item.verify : /[\s\S.]*/g,
                message: item.tooltips,
                trigger,
              },
            ],
            props: {
              label: 'value',
              value: 'key'
            }
          })
        })
      }
    },
    changeFun( prop) {
      this.attachOption.column[1].data[prop]=this.attachForm[prop]
    },
    getDataList(type, dicData) {
      if (type === "truefalse") {
        return [
          {
            key: false,
            value: "否",
          },
          {
            key: true,
            value: "是",
          },
        ];
      } else if (type === "combox") {
        return dicData;
      }
      return [];
    },
    setParams(){
      var queryMap = {
        currentButtonKey:'VIEW',
        ownbizOid:this.options.ownbizOid,
        ownbizBtm:this.options.ownbizBtm
      };
      if(this.options.where){
        Object.assign(queryMap,this.options.where);
      }
      this.params=queryMap;
    },
    handleUpload() {
      this.attachOption.column[1].data.fileOid='';
      delete this.attachOption.column[1].data.oid;
      delete this.attachOption.column[1].data.updateFileFlag;
      this.attachBox = true;
    },
    handleEdit() {
      if(this.selectionList.length==0){
        this.$message.error('请选择需要修改的文件')
        return false;
      }else if(this.selectionList.length>1){
        this.$message.error('请选择一条数据')
        return false;
      }
      this.attachOption.column[1].data.fileOid=this.oids;
      this.attachOption.column[1].data.oid=this.oids;
      this.attachOption.column[1].data.updateFileFlag=true
      this.attachBox = true;
    },
    uploadBefore(file, done, loading,column) {
      done();
    },
    uploadAfter(res, done, loading, column) {
      if(res.success){
        this.attachBox = false;
        this.$message.success('文件上传成功')
      }else{
        this.$message.error(res.msg);
      }
      this.refreshChange();
      done();
    },
    uploadError(error, column) {
      this.$message.error('上传文件出现了异常')
    },
    handleDownload(row) {
      //window.open(`${row.link}`);
      download(row.oid)
    },
    rowDel(row) {
      this.$confirm("确定将选择文件删除?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return remove(row.oid);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        });
    },
    handleDelete() {
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }
      this.$confirm("确定将选择数据删除?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return remove(this.oids);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          this.$refs.crud.toggleSelection();
        });
    },
    beforeOpen(done, type) {
      if (["edit", "view"].includes(type)) {
        getDetail(this.form.id).then(res => {
          this.form = res.data.data;
        });
      }
      done();
    },
    searchReset() {
      this.query = {};
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page);
      done();
    },
    selectionChange(list) {
      this.selectionList = list;
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page, this.query);
    },
    onLoad(page, params={}) {
      this.loading = true;
      var query={}
      if (this.query) {
        for (var key in this.query) {
          query['conditionMap["' + key + '"]'] = this.query[key];
        }
      }
      getList(page.currentPage, page.pageSize, Object.assign(params,this.params, query,this.query)).then(res => {
        const data = res.data.data;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
        this.selectionClear();
      });
    }
  }
};
</script>

<style>
</style>
